Structs
- Cairo
Lint - Cairo
Lint Allow - Plugin with
declared_allowsmatching these ofCairoLintthat does not emit diagnostics. Add it whenCairoLintis not present to avoid compiler warnings on unsupportedallowattribute arguments.
declared_allows matching these of CairoLint that does not emit diagnostics.
Add it when CairoLint is not present to avoid compiler warnings on unsupported
allow attribute arguments.